@@ -31,6 +31,20 @@ namespace quickjsr {
     return res;
   }
 
+  template <typename T, enable_if_type_t<uint32_t, T>* = nullptr>
+  T JSValue_to_Cpp(JSContext* ctx, JSValue val) {
+    uint32_t res;
+    JS_ToUint32(ctx, &res, val);
+    return res;
+  }
+
+  template <typename T, enable_if_type_t<int64_t, T>* = nullptr>
+  T JSValue_to_Cpp(JSContext* ctx, JSValue val) {
+    int64_t res;
+    JS_ToInt64(ctx, &res, val);
+    return res;
+  }
+
   template <typename T, enable_if_type_t<bool, T>* = nullptr>
   T JSValue_to_Cpp(JSContext* ctx, JSValue val) {
     return static_cast<bool>(JS_ToBool(ctx, val));
@@ -44,15 +58,19 @@ namespace quickjsr {
     return result == "true" ? "TRUE" : result == "false" ? "FALSE" : result;
   }
 
+  template <typename T, enable_if_type_t<const char*, T>* = nullptr>
+  T JSValue_to_Cpp(JSContext* ctx, JSValue val) {
+    return JSValue_to_Cpp<std::string>(ctx, val).c_str();
+  }
+
   template <typename T, typename std::enable_if<is_std_vector<T>::value>::type* = nullptr>
   T JSValue_to_Cpp(JSContext* ctx, JSValue val) {
     T res;
-    uint32_t len;
-    JSValue arr_len = JS_GetPropertyStr(ctx, val, "length");
-    JS_ToUint32(ctx, &len, arr_len);
-    JS_FreeValue(ctx, arr_len);
-    for (uint32_t i = 0; i < len; i++) {
-      JSValue elem = JS_GetPropertyUint32(ctx, val, i);
+    int64_t len;
+    JS_GetLength(ctx, val, &len);
+    res.reserve(len);
+    for (int64_t i = 0; i < len; i++) {
+      JSValue elem = JS_GetPropertyInt64(ctx, val, i);
       res.push_back(JSValue_to_Cpp<value_type_t<T>>(ctx, elem));
       JS_FreeValue(ctx, elem);
     }
